@@ -1,16 +1,16 @@
 # ARandR -- Another XRandR GUI
 # Copyright (C) 2008 -- 2011 chrysn <chrysn@fsfe.org>
-# 
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -18,27 +18,33 @@
 
 Run by calling the main() function."""
 
-import gtk
+# pylint: disable=wrong-import-position
+
+import gi
+gi.require_version('Gtk', '3.0')
+from gi.repository import Gtk
+
 from . import widget
 
+
 def main():
-    w = gtk.Window()
-    w.connect('destroy',gtk.main_quit)
+    window = Gtk.Window()
+    window.connect('destroy', Gtk.main_quit)
 
-    r = widget.ARandRWidget()
-    r.load_from_x()
+    arandr = widget.ARandRWidget(window=window)
+    arandr.load_from_x()
 
-    b = gtk.Button("Reload")
-    b.connect('clicked', lambda *args: r.load_from_x())
+    reload_button = Gtk.Button("Reload")
+    reload_button.connect('clicked', lambda *args: arandr.load_from_x())
 
-    b2 = gtk.Button("Apply")
-    b2.connect('clicked', lambda *args: r.save_to_x())
+    apply_button = Gtk.Button("Apply")
+    apply_button.connect('clicked', lambda *args: arandr.save_to_x())
 
-    v = gtk.VBox()
-    w.add(v)
-    v.add(r)
-    v.add(b)
-    v.add(b2)
-    w.set_title('Simple ARandR Widget Demo')
-    w.show_all()
-    gtk.main()
+    vbox = Gtk.VBox()
+    window.add(vbox)
+    vbox.add(arandr)
+    vbox.add(reload_button)
+    vbox.add(apply_button)
+    window.set_title('Simple ARandR Widget Demo')
+    window.show_all()
+    Gtk.main()
